@@ -139,7 +139,7 @@ class RecursiveOptionParser(optparse.OptionParser):
 
     def setmanpageoption(self):
         """
-        creates a manpage option that allows the optionparser to generate a
+        Creates a manpage option that allows the optionparser to generate a
         manpage.
         """
         manpageoption = ManPageOption(
@@ -163,37 +163,43 @@ class RecursiveOptionParser(optparse.OptionParser):
         def formatToolkit(x):
             return x.replace("%prog", "Translate Toolkit")
 
-        result.append('.\\" Autogenerated manpage\n')
-        result.append(
-            f'.TH {prog} 1 "{formatToolkit(self.version)}" "" "{formatToolkit(self.version)}"\n'
-        )
-        result.append(".SH NAME\n")
-        result.append(
-            "{} \\- {}\n".format(
-                self.get_prog_name(), self.description.split("\n\n")[0]
+        result.extend(
+            (
+                '.\\" Autogenerated manpage\n',
+                f'.TH {prog} 1 "{formatToolkit(self.version)}" "" "{formatToolkit(self.version)}"\n',
+                ".SH NAME\n",
+                "{} \\- {}\n".format(
+                    self.get_prog_name(), self.description.split("\n\n")[0]
+                ),
+                ".SH SYNOPSIS\n",
+                ".PP\n",
             )
         )
-        result.append(".SH SYNOPSIS\n")
-        result.append(".PP\n")
         usage = "\\fB%prog "
         usage += " ".join(self.getusageman(option) for option in self.option_list)
         usage += "\\fP"
         result.append(f"{formatprog(usage)}\n")
         description_lines = self.description.split("\n\n")[1:]
         if description_lines:
-            result.append(".SH DESCRIPTION\n")
-            result.append(
-                "\n\n".join(
-                    re.sub(r"\.\. note::", "Note:", l) for l in description_lines
+            result.extend(
+                (
+                    ".SH DESCRIPTION\n",
+                    "\n\n".join(
+                        re.sub(r"\.\. note::", "Note:", l) for l in description_lines
+                    ),
                 )
             )
         result.append(".SH OPTIONS\n")
         ManHelpFormatter().store_option_strings(self)
         result.append(".PP\n")
         for option in self.option_list:
-            result.append(".TP\n")
-            result.append("{}\n".format(str(option).replace("-", r"\-")))
-            result.append("{}\n".format(option.help.replace("-", r"\-")))
+            result.extend(
+                (
+                    ".TP\n",
+                    "{}\n".format(str(option).replace("-", "\\-")),
+                    "{}\n".format(option.help.replace("-", "\\-")),
+                )
+            )
         return "".join(result)
 
     def print_manpage(self, file=None):
@@ -204,7 +210,7 @@ class RecursiveOptionParser(optparse.OptionParser):
 
     def set_usage(self, usage=None):
         """
-        sets the usage string - if usage not given, uses getusagestring for
+        Sets the usage string - if usage not given, uses getusagestring for
         each option.
         """
         if usage is None:
@@ -313,7 +319,7 @@ class RecursiveOptionParser(optparse.OptionParser):
                 outputformats.append(outputformat)
             if templateformat not in templateformats:
                 templateformats.append(templateformat)
-            self.outputoptions[(inputformat, templateformat)] = (
+            self.outputoptions[inputformat, templateformat] = (
                 outputformat,
                 processor,
             )
@@ -322,6 +328,7 @@ class RecursiveOptionParser(optparse.OptionParser):
             "-i",
             "--input",
             dest="input",
+            action="append",
             default=None,
             metavar="INPUT",
             help=f"read from INPUT in {inputformathelp}",
@@ -454,11 +461,11 @@ class RecursiveOptionParser(optparse.OptionParser):
     def getoutputoptions(self, options, inputpath, templatepath):
         """Works out which output format and processor method to use..."""
         if inputpath:
-            inputbase, inputext = self.splitinputext(inputpath)
+            _inputbase, inputext = self.splitinputext(inputpath)
         else:
             inputext = None
         if templatepath:
-            templatebase, templateext = self.splittemplateext(templatepath)
+            _templatebase, templateext = self.splittemplateext(templatepath)
         else:
             templateext = None
         if (inputext, templateext) in self.outputoptions:
@@ -538,7 +545,7 @@ class RecursiveOptionParser(optparse.OptionParser):
         Parses the arguments, and runs recursiveprocess with the resulting
         options...
         """
-        (options, args) = self.parse_args()
+        (options, _args) = self.parse_args()
         self.recursiveprocess(options)
 
     def recursiveprocess(self, options):
@@ -827,7 +834,7 @@ class RecursiveOptionParser(optparse.OptionParser):
         """Gets an output filename based on the input filename."""
         if not inputname or not options.recursiveoutput:
             return options.output
-        inputbase, inputext = self.splitinputext(inputname)
+        inputbase, _inputext = self.splitinputext(inputname)
         outputname = inputbase
         if outputformat:
             outputname += os.extsep + outputformat
@@ -835,5 +842,5 @@ class RecursiveOptionParser(optparse.OptionParser):
 
     def isvalidinputname(self, inputname):
         """Checks if this is a valid input filename."""
-        inputbase, inputext = self.splitinputext(inputname)
+        _inputbase, inputext = self.splitinputext(inputname)
         return (inputext in self.inputformats) or ("*" in self.inputformats)
