@@ -63,8 +63,7 @@ def not_found(environ, start_response):
     """Respond with a 404."""
     start_response("404 Not Found", [("Content-Type", "text/plain")])
     return [
-        "404 Not Found\n\n"
-        "The server has not found anything matching the Request-URI."
+        "404 Not Found\n\nThe server has not found anything matching the Request-URI."
     ]
 
 
@@ -160,13 +159,12 @@ class Selector:
         )
         unnamed, named = [], {}
         for k, v in svars.items():
-            if k.startswith("__pos"):
-                k = k[5:]
+            k = k.removeprefix("__pos")
             named[k] = v
         environ["selector.vars"] = dict(named)
         for k in named:
             if k.isdigit():
-                unnamed.append((k, named.pop(k)))
+                unnamed.append((k, named.pop(k)))  # noqa: PERF401
         unnamed.sort()
         unnamed = [v for k, v in unnamed]
         cur_unnamed, cur_named = environ.get("wsgiorg.routing_args", ([], {}))
@@ -272,12 +270,10 @@ class Selector:
         if not line.strip() or line.strip()[0] == "#":
             pass
         elif not line.strip() or line.strip()[0] == "@":
-            #
             if path and methods:
                 self.add(path, methods)
             path = line.strip()
             methods = {}
-            #
             parts = line.strip()[1:].split(" ", 1)
             if len(parts) == 2:
                 directive, rest = parts
@@ -356,8 +352,8 @@ class SimpleParser:
             pattern = self.patterns[pattern]
         else:
             pattern = self.patterns[self.default_pattern]
-        if name == "":
-            name = "__pos%s" % self._pos
+        if not name:
+            name = f"__pos{self._pos}"
             self._pos += 1
         return f"(?P<{name}>{pattern})"
 
@@ -368,7 +364,7 @@ class SimpleParser:
 
         Adds the ^ and the $ to the beginning and the end, respectively.
         """
-        return "^%s$" % regex
+        return f"^{regex}$"
 
     @staticmethod
     def openended(regex):
@@ -378,7 +374,7 @@ class SimpleParser:
         Adds the ^ to the beginning but no $ to the end.
         Called as a special alternative to lastly.
         """
-        return "^%s" % regex
+        return f"^{regex}"
 
     def outermost_optionals_split(self, text):
         """Split out optional portions by outermost matching delims."""
@@ -413,7 +409,7 @@ class SimpleParser:
         if self.ostart in text:
             parts = self.outermost_optionals_split(text)
             parts = map(self.parse, parts)
-            parts[1::2] = ["(%s)?" % p for p in parts[1::2]]
+            parts[1::2] = [f"({p})?" for p in parts[1::2]]
         else:
             parts = [part.split(self.end) for part in text.split(self.start)]
             parts = [y for x in parts for y in x]
